@@ -666,7 +666,7 @@ class Windmill:
         from wmill import S3Object
 
         s3_obj = S3Object(s3="/path/to/my_file.txt")
-        with wmill.load_s3_file(s3object, s3_resource_path) as file_reader:
+        with wmill.load_s3_file_reader(s3object, s3_resource_path) as file_reader:
             print(file_reader.read())
         '''
         """
@@ -1478,16 +1478,16 @@ def task(*args, **kwargs):
                 params = {}
                 if tag is not None:
                     params["tag"] = tag
-                r = _client.post(
+                w_as_code_response = _client.post(
                     f"/w/{w_id}/jobs/run/workflow_as_code/{job_id}/{f_name}",
                     json={"args": json},
                     params=params,
                 )
-                job_id = r.text
+                job_id = w_as_code_response.text
                 print(f"Executing task {func.__name__} on job {job_id}")
-                r = _client.wait_job(job_id)
+                job_result = _client.wait_job(job_id)
                 print(f"Task {func.__name__} ({job_id}) completed")
-                return r
+                return job_result
 
             return inner
 
@@ -1523,3 +1523,21 @@ def parse_variable_syntax(s: str) -> Optional[str]:
     if s.startswith("var://"):
         return s[6:]
     return None
+
+
+def append_to_result_stream(text: str) -> None:
+    """Append a text to the result stream.
+    
+    Args:
+        text: text to append to the result stream
+    """
+    print("WM_STREAM: {}".format(text.replace(chr(10), '\\n')))
+
+def stream_result(stream) -> None:
+    """Stream to the result stream.
+    
+    Args:
+        stream: stream to stream to the result stream
+    """
+    for text in stream:
+        append_to_result_stream(text)
